@@ -91,89 +91,26 @@ def convert_conv(node, params, layers, lambda_func, node_name, keras_name):
 
         W = W.transpose(2, 3, 1, 0)
         height, width, channels_per_group, out_channels = W.shape
-        in_channels = channels_per_group * n_groups
-
-        if n_groups == in_channels and n_groups != 1:
-            logger.debug('Number of groups is equal to input channels, use DepthWise convolution')
-            W = W.transpose(0, 1, 3, 2)
-            if has_bias:
-                weights = [W, bias]
-            else:
-                weights = [W]
-
-            conv = keras.layers.DepthwiseConv2D(
-                kernel_size=(height, width),
-                strides=(strides[0], strides[1]),
-                padding='valid',
-                use_bias=has_bias,
-                activation=None,
-                depth_multiplier=1,
-                weights=weights,
-                dilation_rate=dilation,
-                name=keras_name
-            )
-            layers[node_name] = conv(input_0)
-
-        elif n_groups != 1:
-            logger.debug('Number of groups more than 1, but less than number of in_channel, use group convolution')
-
-            # Example from https://kratzert.github.io/2017/02/24/finetuning-alexnet-with-tensorflow.html
-            def target_layer(x, groups=n_groups, stride_y=strides[0], stride_x=strides[1]):
-                import tensorflow as tf
-                from tensorflow.keras import backend as K
-                data_format = 'NCHW' if K.image_data_format() == 'channels_first' else 'NHWC'
-
-                if data_format == 'NCHW':
-                    x = tf.transpose(x, [0, 2, 3, 1])
-
-                def convolve_lambda_biased(i, k, b):
-                    import tensorflow as tf
-                    conv = tf.nn.conv2d(i, k, strides=[1, stride_y, stride_x, 1], dilations=[1, dilation, dilation, 1],
-                                        padding='VALID', data_format='NHWC')
-                    return tf.nn.bias_add(conv, b, data_format='NHWC')
-
-                def convolve_lambda(i, k):
-                    import tensorflow as tf
-                    return tf.nn.conv2d(i, k, strides=[1, stride_y, stride_x, 1], dilations=[1, dilation, dilation, 1],
-                                        padding='VALID', data_format='NHWC')
-
-                input_groups = tf.split(axis=3, num_or_size_splits=groups, value=x)
-                weight_groups = tf.split(axis=3, num_or_size_splits=groups, value=W)
-                if has_bias:
-                    bias_groups = tf.split(axis=0, num_or_size_splits=groups, value=bias)
-                    output_groups = [convolve_lambda_biased(i, k, b) for i, k, b in
-                                     zip(input_groups, weight_groups, bias_groups)]
-                else:
-                    output_groups = [convolve_lambda(i, k) for i, k in zip(input_groups, weight_groups)]
-
-                layer = tf.concat(axis=3, values=output_groups)
-                if data_format == 'NCHW':
-                    layer = tf.transpose(layer, [0, 3, 1, 2])
-
-                return layer
-
-            lambda_layer = keras.layers.Lambda(target_layer)
-            layers[node_name] = lambda_layer(input_0)
 
+        if has_bias:
+            weights = [W, bias]
         else:
-            if has_bias:
-                weights = [W, bias]
-            else:
-                weights = [W]
+            weights = [W]
 
-            conv = keras.layers.Conv2D(
-                filters=out_channels,
-                kernel_size=(height, width),
-                strides=(strides[0], strides[1]),
-                padding='valid',
-                weights=weights,
-                use_bias=has_bias,
-                activation=None,
-                dilation_rate=dilation,
-                name=keras_name
-            )
+        conv = keras.layers.Conv2D(
+            filters=out_channels,
+            kernel_size=(height, width),
+            strides=(strides[0], strides[1]),
+            padding='valid',
+            weights=weights,
+            use_bias=has_bias,
+            activation=None,
+            dilation_rate=dilation,
+            groups=n_groups,
+            name=keras_name
+        )
 
-            layers[node_name] = conv(input_0)
+        layers[node_name] = conv(input_0)
     else:
         # 1D conv
         W = W.transpose(2, 1, 0)
@@ -199,6 +136,7 @@ def convert_conv(node, params, layers, lambda_func, node_name, keras_name):
                 use_bias=has_bias,
                 activation=None,
                 dilation_rate=dilation,
+                groups=n_groups,
                 name=keras_name,
                 data_format='channels_first')
         else:
@@ -211,6 +149,7 @@ def convert_conv(node, params, layers, lambda_func, node_name, keras_name):
                 use_bias=has_bias,
                 activation=None,
                 dilation_rate=dilation,
+                groups=n_groups,
                 name=keras_name,
                 data_format='channels_first')
 
