@@ -75,7 +75,7 @@ def convert_gather(node, params, layers, lambda_func, node_name, keras_name):
     """
     logger = logging.getLogger('onnx2keras.gather')
 
-    if is_numpy(layers[node.input[0]]) and is_numpy(layers[node.input[1]]):
+    if is_numpy(layers[node.input[0]]) and is_numpy(layers[node.input[1]]) and not 'is_embedding' in params:
         logger.debug('Gather from numpy array')
 
         if params['axis'] == 0:
@@ -99,7 +99,10 @@ def convert_gather(node, params, layers, lambda_func, node_name, keras_name):
             if len(input_0.shape) == 2:
                 emb = tf.keras.layers.Embedding(input_0.shape[0], input_0.shape[1], weights=[layers[node.input[0]]],
                                                 name=keras_name)
-                layers[node_name] = emb(indices)
+                if isinstance(indices, list):
+                    layers[node_name] = emb(np.array(indices))
+                else:
+                    layers[node_name] = emb(indices)
             else:
                 raise AttributeError("Cannot transform gather into embedding with non 2D array")
         else:
@@ -127,23 +130,17 @@ def convert_concat(node, params, layers, lambda_func, node_name, keras_name):
     else:
         logger.debug('Concat Keras layers.')
         if len(layer_input) > 1:
-            try:
-                layers[node_name] = keras.layers.concatenate(inputs=layer_input,
-                                                             axis=params['axis'],
-                                                             name=keras_name)
-            except:
-                logger.warning('!!! IMPORTANT INFORMATION !!!')
-                logger.warning('Something goes wrong with concat layers. Will use TF fallback.')
-                logger.warning('---')
+            if not np.array([tf.is_tensor(layer_input[i]) and tf.keras.backend.is_keras_tensor(layer_input[i]) for i in range(len(layer_input))]).all():
+                try:
+                    layers[node_name] = tf.concat(layer_input, axis=params['axis'], name=keras_name)
+                except Exception as ex:
+                        # might be due to type mismatch between different inputs of tf.concat
+                        raise
 
-                def target_layer(x, axis=params['axis']):
-                    import tensorflow as tf
-                    x = tf.concat(x, axis=axis)
-                    return x
-
-                lambda_layer = keras.layers.Lambda(target_layer, name="%s_CHW" % keras_name)
-                layers[node_name] = lambda_layer(layer_input)
-                lambda_func["%s_CHW" % keras_name] = target_layer
+            else:
+                    layers[node_name] = keras.layers.concatenate(inputs=layer_input,
+                                                                 axis=params['axis'],
+                                                                 name=keras_name)
         else:
             layers[node_name] = layer_input[0]
 
@@ -229,7 +226,10 @@ def convert_unsqueeze(node, params, layers, lambda_func, node_name, keras_name):
     logger = logging.getLogger('onnx2keras.unsqueeze')
 
     if len(node.input) != 1:
-        raise AttributeError('Number of inputs is not equal 1 for unsqueeze layer')
+        if len(node.input) == 2:
+            params['axes'] = layers[node.input[1]]
+        else:
+            raise AttributeError('Number of inputs is not equal 1 for unsqueeze layer')
 
     if is_numpy(layers[node.input[0]]):
         logger.debug('Work with numpy types.')
@@ -294,16 +294,31 @@ def convert_slice(node, params, layers, lambda_func, node_name, keras_name):
             ends = params["ends"][0]
             starts = params["starts"][0]
         else:
-            raise AttributeError('Not implemented')
+            try:
+                assert len(layers[node.input[1]]) == 1 and len(layers[node.input[2]]) == 1 \
+                        and len(layers[node.input[3]]) == 1
+                if len(node.input) == 4:
+                    axes = layers[node.input[3]][0]
+                    starts = layers[node.input[1]][0]
+                    ends = layers[node.input[2]][0]
+                    steps = 1
+                else:
+                    assert (len(node.input) == 5)
+                    axes = layers[node.input[3]][0]
+                    starts = layers[node.input[1]][0]
+                    ends = layers[node.input[2]][0]
+                    steps = layers[node.input[4]][0]
+            except:
+                raise AttributeError('Not implemented')
 
         if axes == 0:
-            layers[node_name] = layers[node.input[0]][starts:ends]
+            layers[node_name] = layers[node.input[0]][starts:ends:steps]
         elif axes == 1:
-            layers[node_name] = layers[node.input[0]][:, starts:ends]
+            layers[node_name] = layers[node.input[0]][:, starts:ends:steps]
         elif axes == 2:
-            layers[node_name] = layers[node.input[0]][:, :, starts:ends]
+            layers[node_name] = layers[node.input[0]][:, :, starts:ends:steps]
         elif axes == 3:
-            layers[node_name] = layers[node.input[0]][:, :, :, starts:ends]
+            layers[node_name] = layers[node.input[0]][:, :, :, starts:ends:steps]
         else:
             raise AttributeError('Not implemented')
     else:
@@ -392,12 +407,11 @@ def convert_resize(node, params, layers, lambda_func, node_name, keras_name):
     logger = logging.getLogger('onnx2keras.reshape')
 
     input_tensor = layers[node.input[0]]
-    roi = layers[node.input[1]]
-    scales = layers[node.input[2]]
+    roi = None if len(node.input[1]) == 0 else layers[node.input[1]]
+    scales = [] if len(node.input[2]) == 0 else layers[node.input[2]]
     sizes = None
     if len(node.input) == 4:
         sizes = layers[node.input[3]]
-
     if roi:
         raise Exception("Resize with roi not supported")
 
@@ -405,6 +419,8 @@ def convert_resize(node, params, layers, lambda_func, node_name, keras_name):
         resize_method = ResizeMethod.NEAREST_NEIGHBOR
     elif params['mode'] == b'cubic':
         resize_method = ResizeMethod.BICUBIC
+    elif params['mode'] == b'linear':
+        resize_method = ResizeMethod.BILINEAR
     else:
         raise Exception("unsupported resize method")
 
@@ -417,13 +433,12 @@ def convert_resize(node, params, layers, lambda_func, node_name, keras_name):
         tf_resize_shapes = [int(scales[2] * to_channel_last.shape[1]),
                             int(scales[3] * to_channel_last.shape[2])]
     else:
-        if sizes[0] != 1 or sizes[1] != 1:
+        if sizes[0] != input_tensor.shape[0] or sizes[1] != input_tensor.shape[1]:
             raise Exception("Resize of channels or batch dim not suppported")
         tf_resize_shapes = [int(sizes[2]), int(sizes[3])]
 
     resized = tf.image.resize(to_channel_last,
-                              size=[int(scales[2] * to_channel_last.shape[1]),
-                                    int(scales[3] * to_channel_last.shape[2])],
+                              size=tf_resize_shapes,
                               method=resize_method)
     to_channel_first = keras.layers.Permute((3, 1, 2))(resized)
     layers[node_name] = to_channel_first
